==> bouml_4.16.2.orig.tar.gz: bouml_4.16.2/src/CppReverse/UmlAttribute.h <==
// *************************************************************************
//
// Copyright 2004-2009 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLATTRIBUTE_H
#define UMLATTRIBUTE_H

#include "UmlBaseAttribute.h"

class Class;

class UmlAttribute : public UmlBaseAttribute {
  public:
    UmlAttribute(void * id, const QCString & n)
      :  UmlBaseAttribute(id, n) {};
  
    static bool new_one(Class * cl, const QCString & name, const QCString & type,
			const QCString & modifier, const QCString & pretype, 
			const QCString & array,	aVisibility visibility,
			bool staticp, bool constp, bool typenamep, bool mutablep,
			bool volatilep,	const QCString & bitfield,
			const QCString & value,	QCString comment,
			QCString description);
};

#endif

==> bouml_4.21.orig.tar.gz: bouml_4.21/src/CppReverse/UmlAttribute.h <==
// *************************************************************************
//
// Copyright 2004-2010 Bruno PAGES  .
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLATTRIBUTE_H
#define UMLATTRIBUTE_H

#include "UmlBaseAttribute.h"

class Class;

class UmlAttribute : public UmlBaseAttribute {
  public:
    UmlAttribute(void * id, const QCString & n)
      :  UmlBaseAttribute(id, n) {};
  
    static bool new_one(Class * cl, const QCString & name, const QCString & type,
			const QCString & modifier, const QCString & pretype, 
			const QCString & array,	aVisibility visibility,
			bool staticp, bool constp, bool typenamep, bool mutablep,
			bool volatilep,	const QCString & bitfield,
			const QCString & value,	QCString comment,
			QCString description
#ifdef ROUNDTRIP
			, bool roundtrip, QList<UmlItem> & expected_order
#endif
			);
#ifdef ROUNDTRIP
    static UmlAttribute * search_attr(UmlClass * cl, const QCString & name);
#endif
};

#endif
